@@ -28,6 +28,16 @@ def kill_host(host: str):
         del db[host]
 
 
+def is_alive(pid: int) -> bool:
+    '''Returns True if a proccess exists and isn't a zombie.'''
+    proc_dir = Path(f'/proc/{pid}')
+    if not proc_dir.exists():
+        return False
+    if 'State:	Z' in (proc_dir / 'status').read_text():
+        return False
+    return True
+
+
 def start_forward(host: str, forwards: list[str]) -> str:
     '''Inicia um forward usando SSH e salva o pid do SSH num BD.'''
     if isinstance(forwards, str):
@@ -37,8 +47,7 @@ def start_forward(host: str, forwards: list[str]) -> str:
     # TODO: Only works for 1 socket...
     socket = str(sockets_folder / f'{host}.sock')
 
-    pid = get_pid(host)
-    if pid and Path(f'/proc/{pid}').exists():
+    if (pid := get_pid(host)) and is_alive(pid):
         return socket
 
     cmd = f'ssh {host} -o StreamLocalBindUnlink=yes -nTN'
